@@ -7,14 +7,10 @@ import gspread
 from oauth2client.service_account import ServiceAccountCredentials
 
 try:
-    from django.utils.functional import cached_property
+    from pip._vendor.distlib.util import cached_property
 except ImportError:
     cached_property = property
 
-__author__ = 'ytyng'
-__version__ = '0.1.1'
-__license__ = 'MIT'
-
 
 class GSpreadDictIncompleteConfigured(Exception):
     pass
@@ -56,7 +52,7 @@ class GSpreadDictManager(object):
     def gspread_document(self):
         return self.gspread_client.open_by_key(self.owner.spreadsheet_key)
 
-    @cached_property
+    @property
     def worksheet(self):
         if self.owner.sheet_name:
             for ws in self.gspread_document.worksheets():
@@ -67,7 +63,7 @@ class GSpreadDictManager(object):
         else:
             return self.gspread_document.sheet1
 
-    @cached_property
+    @property
     def _all_values(self):
         return self.worksheet.get_all_values()
 
